@@ -3,7 +3,7 @@ use warnings;
 
 package Devel::JSON;
 
-our $VERSION = '0.901';
+our $VERSION = '0.902';
 
 # Just to allow to be loaded with -d:JSON
 sub DB::DB {}
@@ -12,11 +12,13 @@ use JSON::MaybeXS ();
 
 our @JSON_options;
 
-use Encode ();
+# 2.05: _get_locale_encoding appeared in encoding.pm
+# 2.73: includes my patch for locale encoding on Win32
+use Encode 2.05 ();
 use encoding ();
 my $locale_enc = encoding::_get_locale_encoding;
 
-if ($locale_enc =~ /UTF/i) { # Native JSON encoding
+if (defined($locale_enc) && $locale_enc =~ /UTF/i) { # Native JSON encoding
     binmode(STDOUT, ":encoding($locale_enc)")
 } else {
     @JSON_options = (ascii => 1)
@@ -34,7 +36,7 @@ use Filter::Simple sub {
     # As getting proper source encoding can be tricky on the command line
     # let's convert bytes to the locale encoding: DWIM
     $_ = Encode::decode($locale_enc, $_, Encode::FB_CROAK)
-	unless utf8::is_utf8($_);
+	if defined($locale_enc) && !utf8::is_utf8($_);
 
     $_ = 'print JSON::MaybeXS->new(pretty => 1, canonical => 1, allow_nonref => 1, @Devel::JSON::JSON_options)->encode(scalar do {use utf8;'. $_ . '})'
 };
@@ -63,6 +65,16 @@ Devel::JSON - Easy JSON output for one-liners
         "c": 4
     }
 
+Default output encoding is UTF-x if this is the charset of the locale:
+
+    $ perl -d:JSON -e "qq<\N{SNOWMAN}>"
+    "☃"
+
+Force ASCII output:
+
+    $ perl -d:JSON=ascii -e "qq<\N{SNOWMAN}>"
+    "\u2603"
+
 =head1 DESCRIPTION
 
 If you use this module from the command-line, the last value of your one-liner
@@ -70,7 +82,7 @@ If you use this module from the command-line, the last value of your one-liner
 scalar context.
 
 The output will be either UTF-x (UTF-8, UTF-16...) or just ASCII, depending on
-your locale (check `LC_CTYPE` on Unix or GNU).
+your locale (check C<LC_CTYPE> on Unix or GNU).
 
 As a convenience (because you may want to deal with non-ASCII content in your
 C<-e> source), your code is converted from bytes using the current locale.
@@ -93,7 +105,7 @@ disables the option):
     # Force ASCII output
     $ perl -d:JSON=ascii -e '[1..3]'
 
-    # Disable pretty (note '-' before the name
+    # Disable pretty (note '-' before the name)
     $ perl -d:JSON=-pretty -e '[1..3]'
 
     # Non-ASCII in -e
